summaryrefslogtreecommitdiffstats
path: root/src/normal.c
diff options
context:
space:
mode:
authorzeertzjq <zeertzjq@outlook.com>2024-01-28 19:03:00 +0100
committerChristian Brabandt <cb@256bit.org>2024-01-28 19:03:00 +0100
commitbf321806bf44d59f108fd7e5a0eaead04682701d (patch)
treea85148304c17b07d8d4ca3d028cd844fdba31474 /src/normal.c
parentcf8695d48cdded63043430af5a84185e9614e84c (diff)
patch 9.1.0060: Recorded register cannot be translated using keytrans()v9.1.0060
Problem: Recorded register cannot be translated using keytrans() when it involves character search (iddqd505) Solution: Record a K_IGNORE instead of a K_NOP (zeertzjq) related: #13916 closes: #13925 Signed-off-by: zeertzjq <zeertzjq@outlook.com> Signed-off-by: Christian Brabandt <cb@256bit.org>
Diffstat (limited to 'src/normal.c')
-rw-r--r--src/normal.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/normal.c b/src/normal.c
index fd89b00fd4..8a10b86d75 100644
--- a/src/normal.c
+++ b/src/normal.c
@@ -568,10 +568,10 @@ normal_cmd_get_more_chars(
++no_mapping;
// Vim may be in a different mode when the user types the next key,
// but when replaying a recording the next key is already in the
- // typeahead buffer, so record a <Nop> before that to prevent the
- // vpeekc() above from applying wrong mappings when replaying.
+ // typeahead buffer, so record an <Ignore> before that to prevent
+ // the vpeekc() above from applying wrong mappings when replaying.
++no_u_sync;
- gotchars_nop();
+ gotchars_ignore();
--no_u_sync;
}
}